@@ -1,7 +1,5 @@
 
-import os
 import sys
-sys.path.append(os.path.join(os.path.dirname(__file__), '../'))
 from cjutils.cmd import cmd_base
 
 
